import { HttpClient, PageResult, PResponse } from "../types";
export declare enum SkipType {
    /**
     * 审批通过
     */
    PASS = "PASS",
    /**
     * 退回
     */
    REJECT = "REJECT"
}
/**
 * 待办任务
 */
export interface FlowTask {
    /**
     * 主键
     */
    id: number;
    /**
     * 流程定义的ID
     */
    definitionId: string;
    /**
     * 流程实例ID
     */
    instanceId: string;
    /**
     * 流程名称
     */
    flowName: string;
    /**
     * 业务ID
     */
    businessId: string;
    /**
     * 节点编码
     */
    nodeCode: string;
    /**
     * 节点名称
     */
    nodeName: string;
    /**
     * 节点类型
     * 0: 开始; 1: 中间节点; 2: 结束节点; 3: 互斥网关; 4: 并行网关;
     */
    nodeType: number;
    /**
     * 审批表单是否自定义
     * Y: 是; N: 否;
     */
    formCustom: string;
    /**
     * 审批表单
     */
    formPath: string;
}
/**
 * 待办任务VO
 */
export interface FlowTaskVO extends FlowTask {
    /**
     * 计划审批人
     */
    approver: string;
    /**
     * 转办人
     */
    transferredBy: string;
    /**
     * 委派人
     */
    delegate: string;
    /**
     * 流程状态
     */
    flowStatus: string;
    /**
     * 激活状态
     */
    activityStatus: number;
}
/**
 * 办理任务
 */
export interface CompleteTaskForm {
    /**
     * 任务ID
     */
    taskId: number;
    /**
     * 跳转类型
     */
    skipType: SkipType;
    /**
     * 附件ID
     */
    fileId?: string;
    /**
     * 抄送任意
     */
    flowCopyList?: FlowCopyVO[];
    /**
     * 消息类型
     */
    messageType?: string[];
    /**
     * 办理意见
     */
    message: string;
    /**
     * 消息通知
     */
    notice?: string;
    /**
     * 流程变量
     */
    variables: Record<string, any>;
    /**
     * 弹窗选择的办理人
     */
    assigneeMap?: Record<string, any>;
    /**
     * 扩展变量
     */
    ext?: string;
}
/**
 * 抄送
 */
export interface FlowCopyVO {
    /**
     * 用户ID
     */
    userId: number;
    /**
     * 用户名称
     */
    userName: string;
}
/**
 * 待办审批记录
 */
export interface FlowHisTask {
    id: number;
    /**
     * 流程定义的ID
     */
    definitionId: number;
    /**
     * 流程实例ID
     */
    instanceId: number;
    /**
     * 待办任务ID
     */
    taskId: number;
    /**
     * 业务ID
     */
    businessId: string;
    /**
     * 流程名称
     */
    flowName: string;
    /**
     * 协作方式
     * 1: 审批; 2: 转办; 3: 委派; 4: 会签; 5: 票签; 6: 加签; 7: 减签;
     */
    cooperateType: number;
    /**
     * 开始节点编码
     */
    nodeCode: string;
    /**
     * 开始节点名称
     */
    nodeName: string;
    /**
     * 节点类型
     * 0: 开始; 1: 中间节点; 2: 结束节点; 3: 互斥网关; 4: 并行网关;
     */
    nodeType: number;
    /**
     * 目标节点编码
     */
    targetNodeCode: string;
    /**
     * 结束节点名称
     */
    targetNodeName: string;
    /**
     * 审批人
     */
    approver: string;
    /**
     * 协作者
     */
    collaborator: string;
    /**
     * 跳转类型
     * PASS: 通过; REJECT: 退回; NONE: 无动作;
     */
    skipType: string;
    /**
     * 1: 审批中; 2: 审批通过; 9: 已退回; 10: 失效;
     */
    flowStatus: string;
    /**
     * 审批意见
     */
    message: string;
    /**
     * 审批表单路径
     */
    formPath: string;
    /**
     * 流程变量
     */
    variableMap: Record<string, any>;
    /**
     * 待办任务发起时间
     */
    createTime: Date;
    /**
     * 审批完成时间
     */
    updateTime: Date;
}
declare const _default: (client: HttpClient) => {
    /**
     * 分页待办任务列表
     */
    toDoPage: (flowTask: Partial<FlowTask>, pageNum?: number, pageSize?: number) => PResponse<PageResult<FlowTaskVO>>;
    /**
     * 办理任务
     * @param completeTaskForm 办理任务参数
     */
    completeTask: (completeTaskForm: CompleteTaskForm) => PResponse<void>;
    /**
     * 查询已办任务历史记录
     * @param instanceId 流程实例ID
     */
    doneList: (instanceId: number) => PResponse<FlowHisTask[]>;
};
export default _default;
